local addon, ns = ...
local cfg = ns.cfg

local tags = oUF.Tags

local SVal = function(val)
if val then
if (val >= 1e6) then
return ("%.1fm"):format(val / 1e6)
elseif (val >= 1e3) then
return ("%.1fk"):format(val / 1e3)
else
return ("%d"):format(val)
end
end
end

local function hex(r, g, b)
if r then
if (type(r) == 'table') then
if(r.r) then r, g, b = r.r, r.g, r.b else r, g, b = unpack(r) end
end
return ('|cff%02x%02x%02x'):format(r * 255, g * 255, b * 255)
end
end

tags.Events["BfA:lfdrole"] = "GROUP_ROSTER_UPDATE PLAYER_ROLES_ASSIGNED"
tags.Methods["BfA:lfdrole"] = function(unit)
local role = UnitGroupRolesAssigned(unit)
if role == "HEALER" then
return "|cff8AFF30Heals|r"
elseif role == "TANK" then
return "|cffFFF130Tank|r"
elseif role == "DAMAGER" then
return "|cffFF6161DPS|r"
end
end

tags.Events["BfA:perhp"] = 'UNIT_HEALTH UNIT_MAXHEALTH'
tags.Methods["BfA:perhp"] = function(u)
local m = UnitHealthMax(u)
if(m == 0) then
return 0
else
return math.floor((UnitHealth(u)/m*100+.05)*10)/10
end
end

tags.Events['BfA:hp'] = 'UNIT_HEALTH UNIT_MAXHEALTH'
tags.Methods['BfA:hp']  = function(u)
if UnitIsDead(u) or UnitIsGhost(u) or not UnitIsConnected(u) then
return _TAGS["BfA:DDG"](u)
else
local per = _TAGS["BfA:perhp"](u).."%" or 0
local min, max = UnitHealth(u), UnitHealthMax(u)
if u == "player" then
if min~=max then
return "|cffFFFFFF"..per--return "|cFFFFAAAA"..SVal(min)--.."|r/"..SVal(max).." | "..per
else
return SVal(max)--.." | "..per
end
elseif u == "target" then
if min~=max then
return "|cffFFFFFF"..per--return "|cFFFFAAAA"..SVal(min).."|r/"..SVal(max).." | "..per
else
return SVal(max)
end
else
return per
end
end
end

tags.Events["BfA:raidhp"] = 'UNIT_HEALTH UNIT_CONNECTION PLAYER_FLAGS_CHANGED'
tags.Methods["BfA:raidhp"] = function(u)
if UnitIsDead(u) or UnitIsGhost(u) or not UnitIsConnected(u) then
return _TAGS["BfA:DDG"](u)
else
local per = _TAGS["BfA:perhp"](u).."%" or 0
local min, max = UnitHealth(u), UnitHealthMax(u)

if min~=max then

return "|cffFFFFFF"..per
else
return ""
end
end
end

tags.Events['BfA:color'] = 'UNIT_NAME_UPDATE UNIT_FACTION UNIT_HEALTH'
tags.Methods['BfA:color'] = function(u, r)
local _, class = UnitClass(u)
local reaction = UnitReaction(u, "player")

if UnitIsDead(u) or UnitIsGhost(u) or not UnitIsConnected(u) then
return "|cffA0A0A0"
elseif (UnitIsTapDenied(u)) then
return hex(oUF.colors.tapped)
elseif (u == "pet") then
return hex(oUF.colors.class[class])
elseif (UnitIsPlayer(u)) then
return hex(oUF.colors.class[class])
elseif reaction then
return hex(oUF.colors.reaction[reaction])
else
return hex(1, 1, 1)
end
end

tags.Events["BfA:afkdnd"] = 'PLAYER_FLAGS_CHANGED UNIT_POWER_UPDATE UNIT_MAXPOWER'
tags.Methods["BfA:afkdnd"] = function(unit)
return UnitIsAFK(unit) and "|cffCFCFCF <afk>|r" or UnitIsDND(unit) and "|cffCFCFCF <dnd>|r" or ""
end

tags.Events['BfA:DDG'] = 'UNIT_HEALTH'
tags.Methods['BfA:DDG'] = function(u)
if UnitIsDead(u) then
return "|cffCFCFCF Dead|r"
elseif UnitIsGhost(u) then
return "|cffCFCFCF Ghost|r"
elseif not UnitIsConnected(u) then
return "|cffCFCFCF D/C|r"
end
end

tags.Events['BfA:power'] = 'UNIT_POWER_UPDATE UNIT_MAXPOWER'
tags.Methods['BfA:power']  = function(u)
local min, max = UnitPower(u), UnitPowerMax(u)
if min~=max then
return SVal(min/max*100).." %"
--return SVal(min).."/"..SVal(max)
else
return SVal(max)
end
end

tags.Events['BfA:pp'] = 'UNIT_POWER_UPDATE UNIT_MAXPOWER'
tags.Methods['BfA:pp'] = function(u)
if u == "player" or u == "target" then
local _, str = UnitPowerType(u)
if str then
return hex(oUF.colors.power[str] or {250/255,  75/255,  60/255})..SVal(UnitPower(u))
end
end
end


-- Level
tags.Events["BfA:level"] = "UNIT_LEVEL PLAYER_LEVEL_UP UNIT_CLASSIFICATION_CHANGED"
tags.Methods["BfA:level"] = function(unit)

local c = UnitClassification(unit)
local l = UnitLevel(unit)
local d = GetQuestDifficultyColor(l)

local str = l

if l <= 0 then l = "??" end

if c == "worldboss" then
str = string.format("|cff%02x%02x%02xBoss|r",250,20,0)
elseif c == "eliterare" then
str = string.format("|cff%02x%02x%02x%s|r|cff0080FFR|r+",d.r*255,d.g*255,d.b*255,l)
elseif c == "elite" then
str = string.format("|cff%02x%02x%02x%s|r+",d.r*255,d.g*255,d.b*255,l)
elseif c == "rare" then
str = string.format("|cff%02x%02x%02x%s|r|cff0080FFR|r",d.r*255,d.g*255,d.b*255,l)
else
if not UnitIsConnected(unit) then
str = "??"
else
if UnitIsPlayer(unit) then
str = string.format("|cff%02x%02x%02x%s",d.r*255,d.g*255,d.b*255,l)
elseif UnitPlayerControlled(unit) then
str = string.format("|cff%02x%02x%02x%s",d.r*255,d.g*255,d.b*255,l)
else
str = string.format("|cff%02x%02x%02x%s",d.r*255,d.g*255,d.b*255,l)
end
end
end

return str
end
